@@ -20,7 +20,7 @@
 #detect operating system.
 OS=$(uname -o)
 
-EVENTMESH_HOME=`cd "./.." && pwd`
+EVENTMESH_HOME=`cd $(dirname $0)/.. && pwd`
 
 export EVENTMESH_HOME
 
